<?php

namespace Teknisa\ATE\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\Remote\FileUploader\Server;

class Ate00900ConfiguraServicoVooController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = '';
    protected $parameterBagColumns;
    protected $novoCodigo;
    protected $fileserverPath;
	protected $pathKey;
	protected $undefinedImagePath;
	protected $fileServer;
	protected $exportaConfiguracaoVooProcedure;
    
    public function __construct($crudService, $fileServerParams, $exportaConfiguracaoVooProcedure, $ExportaConfiguracaoEquipamentoProcedure, $novoCodigo) {
        $this->crudService = $crudService;
        $this->fileServer = $fileServerParams;
		$this->fileserverPath = $fileServerParams->getFileserverPath();
		$this->pathKey = $fileServerParams->getPathKey();
		$this->undefinedImagePath = $fileServerParams->getUndefinedImagePath();
		$this->exportaConfiguracaoVooProcedure = $exportaConfiguracaoVooProcedure;
		$this->ExportaConfiguracaoEquipamentoProcedure = $ExportaConfiguracaoEquipamentoProcedure;
		$this->novoCodigo = $novoCodigo;
	}
	
	public function findSubgrupo($request, $response) {
	    $this->dataSourceName = 'ate00900_subgrusemam_itensfat';
		$oldFilterCriteria = $request->getFilterCriteria();
		$conditions = $oldFilterCriteria->getConditions();
		$imageFounded = array(
			'columnName' => 'FILE_SERVER',
			'operator' => '=',
			'value' => $this->fileserverPath
		);
		$imageNotFound = array(
			'columnName' => 'UNDEFINED_IMAGE',
			'operator' => '=',
			'value' => $this->undefinedImagePath
		);
		array_push($conditions, $imageFounded, $imageNotFound);
		$newFilterCriteria = new FilterCriteria($this->dataSourceName, $conditions, $oldFilterCriteria->getPage(), $oldFilterCriteria->getPageSize());
		$newRequest = new DTO\Request\Filter($newFilterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
		parent::find($newRequest, $response);
	}
    
    public function findVoo(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'vootrecho_voo_prefixocia_equipamento';
        $this->parameterBagColumns = array("CDFILIAL","CDCIA","NRORG");
        parent::find($request, $response);
    }
    
    public function findVooVigencia(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'voo_vigencia';
        $this->parameterBagColumns = array("CDFILIAL", "CDCIA", "NRVOO");
        parent::find($request, $response);
    }
    
    public function findEquipVigencia(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'equipamento_vigencia';
        $this->parameterBagColumns = array("CDTRECHO");
        parent::find($request, $response);
    }

    public function salvaVigencia(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['NRSEQPADVOOTREMDATA'] = $myCode = $this->novoCodigo->getCodeByTableName('PADVOOTREMDATA', $this->crudService->getEnvironment()->getNrOrg());
        
        $this->dataSourceNameToSave = 'padvootremdata';
        parent::save($request, $response);
	}
    
    public function replicaVigenciaVoo(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['NRSEQPADVOOTREMDATA'] = $myCode = $this->novoCodigo->getCodeByTableName('PADVOOTREMDATA', $this->crudService->getEnvironment()->getNrOrg());
        $this->dataSourceName = 'padvootremdata';
        $this->effectSave($row, $response);
        $this->proceImportaConfiguracaoVoo($request, $response);
	}

    private function effectSave($row, $dataSourceName){
        $rowSave = $this->fixesColumnsToSave($row);
        $dataSet = new DataSet($this->dataSourceName, array($rowSave));
        $request = new DTO\Request\DataSet($dataSet, '','','');
        $rowToSave = $this->crudService->getRowsToSave($request, $this->dataSourceName);
        $this->crudService->save($this->dataSourceName, $rowToSave);
    }
    private function newRequest($row){
        $rowSave = $row;
        $rowSave['NRSEQPADVOOTREMDATA'] = $row['NRSEQPADVOOTREMDATAORI'];
        $dataSet = new DataSet($this->dataSourceName, array($rowSave));
        return $request = new DTO\Request\DataSet($dataSet, '','','');
    }
    private function fixesColumnsToSave($row){
        $row['__is_new'] = true;
        $row['changed'] = true;
        return $row;
    }
    
    public function replicaVigenciaEquipamento(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['NRSEQPADEQUIPMDATA'] = $myCode = $this->novoCodigo->getCodeByTableName('PADEQUIPMDATA', $this->crudService->getEnvironment()->getNrOrg());
        $this->dataSourceName = 'padequipmdata';
        $this->effectSave($row, $response);
        $this->proceExportaConfiguracaoEquipamento($request, $response);
	}

    public function salvaVigenciaEquipamento(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['NRSEQPADEQUIPMDATA'] = $myCode = $this->novoCodigo->getCodeByTableName('PADEQUIPMDATA', $this->crudService->getEnvironment()->getNrOrg());
        
        $this->dataSourceNameToSave = 'padequipmdata';
        parent::save($request, $response);
	}

	public function proceExportaConfiguracaoVoo(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		$vooDestino = '_';
        for($i=0;$i<count($row['NRVOODES']);$i++) {
        	$vooDestino .= $row['NRVOODES'][$i]['NRVOO'].'|'.$row['NRVOODES'][$i]['CDTRECHO'].'_';
        }
		$this->exportaConfiguracaoVooProcedure->copiaItemfatVoo($row['CDFILIAL'], $row['CDCIA'], $row['NRVOOORI'], $row['CDTRECHOORI'], $row['NRSEQPADVOOTREMDATA'], $vooDestino, $row['DTINIVIGENCIA'], $row['CDOPERADOR'], $row['NRORG']);
    }

    public function proceImportaConfiguracaoVoo(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $vooDestino = '_';
            $vooDestino .= $row['NRVOODES'].'|'.$row['CDTRECHODES'].'_';
		if(!empty($row['NRSEQPADVOOTREMDATAORI'])){
            $row['NRSEQPADVOOTREMDATA'] = $row['NRSEQPADVOOTREMDATAORI'];
        }
        $this->exportaConfiguracaoVooProcedure->copiaItemfatVoo($row['CDFILIAL'], $row['CDCIA'], $row['NRVOOORI'], $row['CDTRECHOORI'], $row['NRSEQPADVOOTREMDATA'], $vooDestino, $row['DTINIVIGENCIA'], $row['CDOPERADOR'], $row['NRORG']);
    }
    
    public function proceExportaConfiguracaoEquipamento(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
		$this->ExportaConfiguracaoEquipamentoProcedure->copiaItemEquipamento($row['CDFILIAL'], $row['CDCIA'], $row['CDEQUIPORI'], $row['NRSEQPADEQUIPMDATAORI'], $row['CDEQUIPDES'], $row['DTINIVIGENCIA'], $row['CDOPERADOR'], $row['NRORG']);
    }
}