<?php
namespace Teknisa\ATE\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Doctrine\DBAL\Connection;

class Ate12200VooTrechoService{

	protected $connection;

	public function __construct(Connection $connection){
		$this->connection = $connection;
	}

	public function salvaVoo($request, $response, $rowVoo, $crudService){
  	$dataSetVoo = new DataSet('voo', [$rowVoo]);
  	$dataSetVooToSave = new DTO\Request\DataSet($dataSetVoo, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
    $saveRowVoo = $crudService->getRowsToSave($dataSetVooToSave, "voo");
    $crudService->save('voo', $saveRowVoo);
	}

	public function salvaTrechos($request, $response, $rowsTrechos, $crudService){
  	$dataSetTrechos = new DataSet('vootrecho', [$rowsTrechos]);
  	$dataSetTrechosToSave = new DTO\Request\DataSet($dataSetTrechos, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
    $saveRowsTrechos = $crudService->getRowsToSave($dataSetTrechosToSave, "vootrecho");
    $crudService->save('vootrecho', $saveRowsTrechos);
	}	

	public function salvaVigencia($request, $response, $rows, $crudService){
	  	$dataSetVigencia = new DataSet('vootrechodata', [$rows]);
	  	$dataSetVigenciaToSave = new DTO\Request\DataSet($dataSetVigencia, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
	    $saveRows = $crudService->getRowsToSave($dataSetVigenciaToSave, "vootrechodata");
	    $crudService->save('vootrechodata', $saveRows);
	}

	public function checkVooCode($nrvoo, $cdfilial, $cdcia, $nrorg, $response) {
		$sql = "SELECT NRVOO FROM VOOTRECHO WHERE NRVOO = :NRVOO AND CDFILIAL = :CDFILIAL AND CDCIA = :CDCIA AND NRORG = :NRORG";
		$stmt = $this->connection->prepare($sql);
		$stmt->execute(
			array(
				"NRVOO" => $nrvoo,
				"CDFILIAL" => $cdfilial,
				"CDCIA" => $cdcia,
				"NRORG" => $nrorg
			)
		);
		$result = $stmt->fetch(\PDO::FETCH_ASSOC);
		if($result) {
			$response->setError(new Error("Já existe um voo com o código informado.", 500));
			return false;
		}
		return true;
	}

	public function validaVigencia($row, $response) {
		$cdfilial = $row['CDFILIAL'];
		$cdcia = $row['CDCIA'];
		$nrvoo = $row['NRVOO'];
		$cdtrecho = $row['CDTRECHO'];
		$nrorg = $row['NRORG'];
		$dtinivigencia = $row['DTINIVIGENCIA'];
		$dtfimvigencia = $row['DTFIMVIGENCIA'];
		$nrseqvootrechodata = array_key_exists('NRSEQVOOTRECHODATA', $row) ? $row['NRSEQVOOTRECHODATA'] : null;
		$sql = "SELECT CDFILIAL, CDCIA, NRVOO, CDTRECHO, NRSEQVOOTRECHODATA, DTINIVIGENCIA, DTFIMVIGENCIA, NRORG FROM VOOTRECHODATA WHERE CDFILIAL = :CDFILIAL AND CDCIA = :CDCIA AND NRVOO = :NRVOO AND CDTRECHO = :CDTRECHO AND NRORG = :NRORG AND ( (DTINIVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA) OR (DTFIMVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA) OR (:DTINIVIGENCIA BETWEEN DTINIVIGENCIA AND DTFIMVIGENCIA) OR (:DTFIMVIGENCIA BETWEEN DTINIVIGENCIA AND DTFIMVIGENCIA) OR (:DTFIMVIGENCIA IS NULL AND DTINIVIGENCIA >= TO_DATE(:DTINIVIGENCIA)) OR (DTFIMVIGENCIA IS NULL AND (:DTFIMVIGENCIA IS NULL OR TO_DATE(:DTINIVIGENCIA) >= DTINIVIGENCIA))) AND NRSEQVOOTRECHODATA <> NVL(:NRSEQVOOTRECHODATA, -1)";
		$stmt = $this->connection->prepare($sql);
		$stmt->execute(
			array(
				"CDFILIAL" => $cdfilial,
				"CDCIA" => $cdcia,
				"NRVOO" => $nrvoo,
				"CDTRECHO" => $cdtrecho,
				"NRORG" => $nrorg,
				"DTINIVIGENCIA" => $dtinivigencia,
				"DTFIMVIGENCIA" => $dtfimvigencia,
				"NRSEQVOOTRECHODATA" => $nrseqvootrechodata
			)
		);
		$result = $stmt->fetch(\PDO::FETCH_ASSOC);
		if($result) {
			$response->setError(new Error("Período de vigência já cadastrado.", 500));
			return false;
		}
		return true;
	}

	public function validaDataDecolagem($row, $response) {
		$cdfilial = $row['CDFILIAL'];
		$cdcia = $row['CDCIA'];
		$nrvoo = $row['NRVOO'];
		$cdtrecho = $row['CDTRECHO'];
		$nrorg = $row['NRORG'];
		$nrseqvootrechodata = $row['NRSEQVOOTRECHODATA'];
		$dtfimvigencia = array_key_exists('DTFIMVIGENCIA', $row) ? $row['DTFIMVIGENCIA'] : null;
		$sql = "SELECT CDFILIAL, CDCIA, NRVOO, CDTRECHO, NRSEQVOOTRECHODATA, DTDIA, NRORG FROM VOOTRECHODATADIA WHERE CDFILIAL = :CDFILIAL AND CDCIA = :CDCIA AND NRVOO = :NRVOO AND CDTRECHO = :CDTRECHO AND NRORG = :NRORG AND (DTDIA>TO_DATE(:DTFIMVIGENCIA) OR :DTFIMVIGENCIA IS NULL) AND NRSEQVOOTRECHODATA = :NRSEQVOOTRECHODATA";
		$stmt = $this->connection->prepare($sql);
		$stmt->execute(
			array(
				"CDFILIAL" => $cdfilial,
				"CDCIA" => $cdcia,
				"NRVOO" => $nrvoo,
				"CDTRECHO" => $cdtrecho,
				"NRORG" => $nrorg,
				"DTFIMVIGENCIA" => $dtfimvigencia,
				"NRSEQVOOTRECHODATA" => $nrseqvootrechodata
			)
		);
		$result = $stmt->fetch(\PDO::FETCH_ASSOC);
		if($result) {
			$response->setError(new Error("Não é possivel remover/alterar fim de vigência. Existem datas de decolagem em conflito com a alteração.", 500));
			return false;
		}
		return true;
	}

	public function removerFilhos($request, $response) {
		try {
			$row = $request->getRow();

			$cdfilial 	= $row['CDFILIAL'];
			$cdcia 		= $row['CDCIA'];
			$nrvoo 		= $row['NRVOO'];
			$nrorg 		= $row['NRORG'];

			$query = "DELETE FROM VOOTRECHO WHERE CDFILIAL = '".$cdfilial."' AND CDCIA = '".$cdcia."' AND NRVOO = '".$nrvoo."' AND NRORG = '".$nrorg."'";

			$this->connection->executeQuery($query);

			return true;
		} catch (\Exception $e) {
			$response->setError(new Error("Erro ao remover filhos. ".$e->getMessage(), 500));
			return false;
		}
	}

	public function removerDecolagens($request, $response) {
		try {
			$row = $request->getRow();

			$cdfilial 	= $row['CDFILIAL'];
			$cdcia 		= $row['CDCIA'];
			$nrvoo 		= $row['NRVOO'];
			$cdtrecho 	= $row['CDTRECHO'];
			$sequencial = $row['NRSEQVOOTRECHODATA'];
			$nrorg 		= $row['NRORG'];

			$query = "DELETE FROM VOOTRECHODATADIA WHERE CDFILIAL = '".$cdfilial."' AND CDCIA = '".$cdcia."' AND NRVOO = '".$nrvoo."' AND CDTRECHO = '".$cdtrecho."' AND NRSEQVOOTRECHODATA = '".$sequencial."' AND NRORG = '".$nrorg."'";

			$this->connection->executeQuery($query);

			return true;
		} catch (\Exception $e) {
			$response->setError(new Error("Erro ao remover. ".$e->getMessage(), 500));
			return false;
		}
	}
}